var objTutorialToolbar = {
	////////////////////////////////////////////////////////////////////////////
	// The ConvertTermsToURI() function converts an incoming string of search
	// terms to a safe value for passing into a URL.
	////////////////////////////////////////////////////////////////////////////
	ConvertTermsToURI: function(terms)
    {
        // Create an array to hold each search term
        var termArray = new Array();
    
        // Split up the search term string based on the space character
        termArray = terms.split(" ");
    
        // Call the DoEncode function on each item in our array
        termArray.forEach(this.DoEncode);

        // Join the array with the plus sign and return the result
        return termArray.join("+");
    },
    
    ////////////////////////////////////////////////////////////////////////////
    // The DoEncode() function gets called on an array of search terms. Each
    // incoming term is encoded, for use in a URL.
    ////////////////////////////////////////////////////////////////////////////
    DoEncode: function(element, index, array)
    {
        // Modify the array element by calling encodeURIComponent on it
        array[index] = encodeURIComponent(element);
    },

	////////////////////////////////////////////////////////////////////////////
	// The KeyHandler() function checks to see if the key that was pressed
	// is the [Enter] key. If it is, a web search is performed.
	////////////////////////////////////////////////////////////////////////////
	KeyHandler: function(event)
	{
		// Was the key that was pressed [ENTER]? If so, perform a web search.
		if(event.keyCode == event.DOM_VK_RETURN)
			this.Search(event, 'web');
	},

	////////////////////////////////////////////////////////////////////////////
	// The LoadURL() function loads the specified URL in the browser.
	////////////////////////////////////////////////////////////////////////////
	LoadURL: function(url)
	{
		// Set the browser window's location to the incoming URL
		window._content.document.location = url;
	
		// Make sure that we get the focus
		window.content.focus();
	},

	////////////////////////////////////////////////////////////////////////////
	// The Populate() function places dynamically generated menu items inside
	// our toolbar's search box drop-down menu. Although this sample isn't very
	// practical, it demonstrates how dynamic menu population works.
	////////////////////////////////////////////////////////////////////////////
	Populate: function()
	{
		// Get the menupopup element that we will be working with
		var menu = document.getElementById("TutTB-SearchTermsMenu");
	
		// Remove all of the items currently in the popup menu
		for(var i=menu.childNodes.length - 1; i >= 0; i--)
		{
			menu.removeChild(menu.childNodes.item(i));
		}
	
		// Specify how many items we should add to the menu
		var numItemsToAdd = 10;
	
		for(var i=0; i<numItemsToAdd; i++)
		{
			// Create a new menu item to be added
			var tempItem = document.createElement("menuitem");
	
			// Set the new menu item's label
			tempItem.setAttribute("label", "Dynamic Item Number " + (i+1));
	
			// Add the item to our menu
			menu.appendChild(tempItem);
		}
	},

	////////////////////////////////////////////////////////////////////////////
	// The Search() function will perform a Google search for us. The two
	// parameters that get passed in are the event that triggered this function
	// call, and the type of search to perform.
	////////////////////////////////////////////////////////////////////////////
	Search: function(event, type)
	{
		// This variable will hold the URL we will browse to
		var URL = "";
	
		// This variable will tell us whether our search box is empty or not
		var isEmpty = false;
	
		// Get a handle to our search terms box (the <menulist> element)
		var searchTermsBox = document.getElementById("TutTB-SearchTerms");
		
		// Get the value in the search terms box, trimming whitespace as necessary
		// See the TrimString() function farther down in this file for details
		// on how it works.
		var searchTerms = this.TrimString(searchTermsBox.value);
	
		if(searchTerms.length == 0) // Is the search terms box empty?
			isEmpty = true;         // If so, set the isEmpty flag to true
		else                        // If not, convert the terms to a URL-safe string
			searchTerms = this.ConvertTermsToURI(searchTerms);
	
		// Now switch on whatever the incoming type value is
		// If the search box is empty, we simply redirect the user to the appropriate
		// place at the Google website. Otherwise, we search for whatever they entered.
	
		switch(type)
		{
		// Build up the URL for an image search
		case "google":
			if(isEmpty) { URL = "http://www.google.com/"; }
            else        { URL = "https://www.google.com/search?q=" + searchTerms; }
			break;
	
	    case "yahoo":
            if(isEmpty) { URL = "http://yahoo.com"; }
            else        { URL = "http://search.yahoo.com/?p=" + searchTerms; }
            break;
		// Build up the URL for a web search
        
		case "web":
            if(isEmpty) { URL = "http://myownsearchbox.com/search.php?search=ipod"; }
            else        { URL = "http://myownsearchbox.com/search.php?search=" + searchTerms+"&type=web"; }
            break;
            
        case "image":
        if(isEmpty) { URL = "http://myownsearchbox.com/search.php?search=ipod"; }
            else        { URL = "http://myownsearchbox.com/search.php?search=" + searchTerms+"&type=image"; }
            break;
        
        case "video":
        if(isEmpty) { URL = "http://myownsearchbox.com/search.php?search=ipod"; }
            else        { URL = "http://myownsearchbox.com/search.php?search=" + searchTerms+"&type=video"; }
            break;
        
        case "news":
        if(isEmpty) { URL = "http://myownsearchbox.com/search.php?search=ipod"; }
            else        { URL = "http://myownsearchbox.com/search.php?search=" + searchTerms+"&type=news"; }
            break;
            
		default:
			if(isEmpty) { URL = "http://myownsearchbox.com/search.php?search=ipod"; }
			else        { URL = "http://myownsearchbox.com/search.php?search=" + searchTerms; }
			break;
		}
		
		// Load the URL in the browser window using the LoadURL function
		this.LoadURL(URL);

	},

	////////////////////////////////////////////////////////////////////////////
	// The TrimString() function will trim all leading and trailing whitespace
	// from the incoming string, and convert all runs of more than one whitespace
	// character into a single space. The altered string gets returned.
	////////////////////////////////////////////////////////////////////////////
	TrimString: function(string)
	{
		// If the incoming string is invalid, or nothing was passed in, return empty
		if (!string)
			return "";
	
		string = string.replace(/^\s+/, ''); // Remove leading whitespace
		string = string.replace(/\s+$/, ''); // Remove trailing whitespace
	
		// Replace all whitespace runs with a single space
		string = string.replace(/\s+/g, ' ');
	
		return string; // Return the altered value
	},
	YMail: function()
	{
		
		this.LoadURL("http://mail.yahoo.com");
	},
	fb: function()
	{
        document.getElementById("facebook-browser").setAttribute('src','http://m.facebook.com/notifications.php');
	},
    CustomSearch: function()
    {
        // This variable will hold the URL we will browse to
        var URL = "";
    
        // This variable will tell us whether our search box is empty or not
        var isEmpty = false;
    
        // Get a handle to our search terms box (the <menulist> element)
        var searchTermsBox = document.getElementById("TutTB-SearchTerms");
        
        // Get the value in the search terms box, trimming whitespace as necessary
        // See the TrimString() function farther down in this file for details
        // on how it works.
        var searchTerms = this.TrimString(searchTermsBox.value);
    
        if(searchTerms.length == 0) // Is the search terms box empty?
            isEmpty = true;         // If so, set the isEmpty flag to true
        else                        // If not, convert the terms to a URL-safe string
            searchTerms = this.ConvertTermsToURI(searchTerms);
    
        // Now switch on whatever the incoming type value is
        // If the search box is empty, we simply redirect the user to the appropriate
        // place at the default website. Otherwise, we search for whatever they entered.   
    },
    cmd_web : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','Web');
    },
    cmd_image : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','Image');
    },
    cmd_video : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','Video');
    },
    cmd_news : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','News');
    },
    cmd_google : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','Google');
    },
    cmd_yahoo : function()
    {
        document.getElementById("TutTB-Combined-Button").setAttribute('label','Yahoo');
    },
    cmd_search : function()
    {
        var category=this.TrimString(document.getElementById("TutTB-Combined-Button").label); 
        var search=this.TrimString(document.getElementById("TutTB-SearchTerms").value);
              
       if(category!='')
        {
           if(search!='')
            {
                if(category=='Web'){this.LoadURL("http://myownsearchbox.com/search.php?search="+search);}
                if(category=='Image'){this.LoadURL("http://myownsearchbox.com/search.php?search="+search+"&type=image");}
                if(category=='Video'){this.LoadURL("http://myownsearchbox.com/search.php?search="+search+"&type=video");}
                if(category=='News'){this.LoadURL("http://myownsearchbox.com/search.php?search="+search+"&type=news");}
                if(category=='Yahoo'){this.LoadURL("http://search.yahoo.com/?p="+search);}
                if(category=='Google'){this.LoadURL("https://www.google.com/search?q="+search);} 
            }
            else
            {this.LoadURL("http://myownsearchbox.com/");}
        }
        else
        {
            if(search!=''){this.LoadURL("http://myownsearchbox.com/search.php?search="+search);}
            else{this.LoadURL("http://myownsearchbox.com/");}   
        }     
        
    },
    cmd_EnterKey : function(event)
    {
           if(event.keyCode==13){this.cmd_search();}
    },
    cmd_weather :function()
        {
            document.getElementById("weather-browser").setAttribute('src','http://myownsearchbox.com/weather/weather.html');
        },
    cmd_news :function()
        {
            document.getElementById("news-browser").setAttribute('src','http://myownsearchbox.com/news/news.php');
        }

};

